# Japtoanki ⚡📖

Extract sentences from Japanese media, pictures, screenshots, etc, using OCR and generate Anki flashcards automatically.

---

## Installation

```bash
pip install japtoanki
```

**Note:** japtoanki includes OCR support by default (will download AI model weights (~400MB) on the first run)

## Usage 

```bash
japtoanki /path/to/manga --deck Kanji_Sentences --tag manga
```

Running japtoanki with no flags will open a basic cli file-navigator.
If the deck given with the `--deck` flag doesn't exist, japtoanki will create a new deck with the given name.

#### Requirements:

- [Python](https://www.python.org/)
- [Anki](https://apps.ankiweb.net/)
- [Anki-connect](https://github.com/amikey/anki-connect)

Requires [Anki-connect](https://github.com/amikey/anki-connect) plugin to be enabled in Anki to work. Anki needs to be open as japtoanki runs.

## Examples

![Anki Card](https://raw.githubusercontent.com/MidoriNoHoshi/JapaneseOCR-to-Anki-Flashcards/main/images/2026-02-10-153400_hyprshot.png) ![Anki Card2](https://raw.githubusercontent.com/MidoriNoHoshi/JapaneseOCR-to-Anki-Flashcards/main/images/2026-02-10-145359_hyprshot.png)

